==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/dsl/internal/DNSRecordOperationsImpl.java <==

                
      

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableDNSRecord;
import io.fabric8.openshift.api.model.operator.v1.DNSRecord;
import io.fabric8.openshift.api.model.operator.v1.DNSRecordList;
import io.fabric8.openshift.api.model.operator.v1.DoneableDNSRecord;

import java.util.Map;
import java.util.TreeMap;


public class DNSRecordOperationsImpl extends OpenShiftOperation<DNSRecord, DNSRecordList, DoneableDNSRecord, Resource<DNSRecord, DoneableDNSRecord>> {

  public DNSRecordOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public DNSRecordOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("ingress.operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("dnsrecords"));
    this.type = DNSRecord.class;
    this.listType = DNSRecordList.class;
    this.doneableType = DoneableDNSRecord.class;
  }

  public DNSRecordOperationsImpl newInstance(OperationContext context) {
    return new DNSRecordOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> openshift-client-5.1.2-sources.jar: io/fabric8/openshift/client/dsl/internal/DNSRecordOperationsImpl.java <==

                            
      

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DNSRecord;
import io.fabric8.openshift.api.model.operator.v1.DNSRecordBuilder;
import io.fabric8.openshift.api.model.operator.v1.DNSRecordList;

import java.util.Map;
import java.util.TreeMap;


public class DNSRecordOperationsImpl extends OpenShiftOperation<DNSRecord, DNSRecordList, Resource<DNSRecord>> {

  public DNSRecordOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public DNSRecordOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("ingress.operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("dnsrecords"));
    this.type = DNSRecord.class;
    this.listType = DNSRecordList.class;
  }

  public DNSRecordOperationsImpl newInstance(OperationContext context) {
    return new DNSRecordOperationsImpl(context);
  }

  @Override
  public DNSRecord edit(Visitor... visitors) {
    return patch(new DNSRecordBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
